#region Copyright Syncfusion Inc. 2001-2015.
// Copyright Syncfusion Inc. 2001-2015. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Linq;
using System.IO;
using System.IO.IsolatedStorage;
using System.Collections.Generic;
using Microsoft.LightSwitch;
using Microsoft.LightSwitch.Framework.Client;
using Microsoft.LightSwitch.Presentation;
using Microsoft.LightSwitch.Presentation.Extensions;
using Syncfusion.LightSwitch.Extension.XlsIO;
namespace LightSwitchApplication
{
    public partial class FormattedFields
    {
        partial void ExportToExcel_Execute()
        {

            Export();
        }
        /// <summary>
        /// Exports based on the document type.
        /// </summary>
        void Export()
        {
            Helper.ShowSaveDialog(SaveDialog_Closed);
        }
        /// <summary>
        /// This event is occured once the file is selected in the SaveFileDialog
        /// and exports the content to stream.
        /// </summary>
        /// <param name="sender">sender is the SaveDialog stream.</param>
        /// <param name="e"></param>
        void SaveDialog_Closed(object sender, EventArgs e)
        {
            SaveFileWindow saveFileWindow = sender as SaveFileWindow;

            if (saveFileWindow != null && saveFileWindow.DocumentStream != null)
            {
                Export(saveFileWindow.DocumentStream);
            }
            else
            {
                Stream stream = sender as Stream;
                if (stream != null)
                {
                    Export(stream);
                }
            }

        }
        /// <summary>
        /// Exports the content to the stream based on the file format.
        /// </summary>
        /// <param name="stream"></param>
        public void Export(Stream stream)
        {
            Func<decimal, string> formatPrice = (decimal x) => { return string.Format("{0:c}", x); };

            Func<string, string> formatTitle = (string x) => { return x.ToUpper(); };

            Func<int, string> formatCategory = (int x) =>
            {
                switch (x)
                {
                    case 0:
                        return "COM+";
                    case 1:
                        return "LightSwitch";
                    case 2:
                        return "VB6";
                    default:
                        return "Other";
                }
            };

            Func<DateTime, string> formatDate = (System.DateTime x) => { return string.Format("{0:d}", x); };

            List<ColumnMapping> columnMappings = new List<ColumnMapping>();
            columnMappings.Add(new ColumnMapping("Book Title", "Title", null, formatTitle));
            columnMappings.Add(new ColumnMapping("Author Name", "Author"));
            columnMappings.Add(new ColumnMapping("Category", "Category", null, formatCategory));
            columnMappings.Add(new ColumnMapping("Rate", "Price", null, formatPrice));
            columnMappings.Add(new ColumnMapping("Publication Date", "PublicationDate", formatDelegate: formatDate));
            columnMappings.Add(new ColumnMapping("CoverImage", "FrontCoverThumbnail"));

            ExportToExcel(columnMappings, stream);
            Helper.ShowSuccessDialog();
        }
        public void ExportToExcel(List<ColumnMapping> columnMappings, Stream stream)
        {
            ExcelExportOptions exportSettings = new ExcelExportOptions();
            exportSettings.Row = 3;
            exportSettings.Column = 2;
            exportSettings.Mappings = columnMappings;
            exportSettings.Mappings.Remove(exportSettings.Mappings[2]);
            exportSettings.Mappings.RemoveAt(2);
            using (stream)
            {
                ExcelBuilder.Export(this.Books, exportSettings, stream);
            }
        }
    }
}
